==> refdb_0.9.9.orig.tar.gz: refdb-0.9.9-1/src/outformats.h <==
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  outformats.h - defines the output types supported by RefDB
  markus@mhoenicka.de 2007-09-08

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/


#ifndef outformats_included
#define outformats_included 1

/* output formats for getref/getnote */
#define REFSCREEN         0
#define REFRIS            1
#define REFDOCBK          2
#define REFBIBTEX         3
#define REFHTML           4
#define REFCGIHTML        6
#define REFCGIRIS         7
#define REFDOCBKX         8
#define REFTEIX           9
#define RISX             10
#define REFXHTML         11
#define XNOTE            12
#define REFCITATIONLISTX 13
#define REFMODS          14
#define REFDOCBKX5       15
#define REFTEIX5         16

/* note types */
#define REFERENCE  1
#define KEYWORD    2
#define AUTHOR     4
#define PERIODICAL 8

#endif /* ifndef outformats_included */

==> refdb_1.0.2.orig.tar.gz: refdb-1.0.2/src/outformats.h <==
/*++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
  outformats.h - defines the output types supported by RefDB
  markus@mhoenicka.de 2007-09-08

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
   
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
   
   You should have received a copy of the GNU General Public License
   along with this program; if not, see <http://www.gnu.org/licenses/>

  ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++*/


#ifndef outformats_included
#define outformats_included 1

/* output formats for getref/getnote */
#define REFSCREEN         0
#define REFRIS            1
#define REFDOCBK          2
#define REFBIBTEX         3
#define REFHTML           4
#define REFCGIHTML        6
#define REFCGIRIS         7
#define REFDOCBKX         8
#define REFTEIX           9
#define RISX             10
#define REFXHTML         11
#define XNOTE            12
#define REFCITATIONLISTX 13
#define REFMODS          14
#define REFDOCBKX5       15
#define REFTEIX5         16
#define REFRTF           17

/* note types */
#define REFERENCE  1
#define KEYWORD    2
#define AUTHOR     4
#define PERIODICAL 8

#endif /* ifndef outformats_included */
